.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Accumulating functions
======================

**xtensor** provides the following accumulating functions for xexpressions:

Defined in ``xtensor/xmath.hpp``

.. _cumsum-function-reference:
.. doxygenfunction:: cumsum(E&&)
   :project: xtensor

.. doxygenfunction:: cumsum(E&&, std::ptrdiff_t)
   :project: xtensor

.. _cumprod-function-reference:
.. doxygenfunction:: cumprod(E&&)
   :project: xtensor

.. doxygenfunction:: cumprod(E&&, std::ptrdiff_t)
   :project: xtensor